import * as React from 'react';
import { IgRect } from "igniteui-react-core";
import { Popup } from './Popup';
import { IgrOnPopupEventArgs } from './igr-on-popup-event-args';
import { IgrOnClosedEventArgs } from './igr-on-closed-event-args';
import { PopupDirection } from "./PopupDirection";
import { PopupAlignment } from "./PopupAlignment";
export declare class IgrPopup extends React.Component<IIgrPopupProps> {
    private _height;
    private _width;
    private _initialized;
    private _elRef;
    private _contentAreaInnerRef;
    private _contentAreaOuterRef;
    private _reactRenderer;
    private _implementation;
    private _portalManager;
    set height(value: string);
    get height(): string;
    set width(value: string);
    get width(): string;
    private _getMainRef;
    private verifyReferences;
    render(): React.DetailedReactHTMLElement<{
        ref: (ref: any) => void;
        children: any[];
    }, any>;
    private requestRender;
    constructor(props: IIgrPopupProps);
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    protected initializeProperties(): void;
    updateStyle(): void;
    componentWillUnmount(): void;
    componentDidMount(): void;
    initializeContent(): void;
    protected createImplementation(): Popup;
    get i(): Popup;
    /**
 * Gets or sets the duration of the Popup and Closeup animations in milliseconds.
*/
    get animationDuration(): number;
    set animationDuration(v: number);
    /**
     * Gets or sets whether the popup and closeup animations are animated.
    */
    get animationEnabled(): boolean;
    set animationEnabled(v: boolean);
    /**
     * Gets or sets the elevation to use for the button regardless of type.
    */
    get elevation(): number;
    set elevation(v: number);
    /**
     * Gets or sets the elevation of the border shadow
    */
    get actualElevation(): number;
    set actualElevation(v: number);
    /**
     * Gets / sets the isShown state of the panel.
    */
    get isShown(): boolean;
    /**
     * Gets or sets the color to use for the check mark when the checkbox is checked.
    */
    get actualUmbraShadowColor(): string;
    set actualUmbraShadowColor(v: string);
    /**
     * Gets or sets the color to use for the check mark when the checkbox is checked.
    */
    get actualPenumbraShadowColor(): string;
    set actualPenumbraShadowColor(v: string);
    /**
     * Gets or sets the color to use for the check mark when the checkbox is checked.
    */
    get actualAmbientShadowColor(): string;
    set actualAmbientShadowColor(v: string);
    /**
     * Gets or sets the background color of the popup.
    */
    get background(): string;
    set background(v: string);
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
 * Closes the popup.

*/
    close(): void;
    showRelativeToExclusionRect(exclusionRect: IgRect, popupDirection: PopupDirection, popupAlignment: PopupAlignment): void;
    /**
     * Exports visual information about the current state of the grid.
    
    */
    exportVisualModel(): any;
    /**
     * Returns a serialized copy of the exported visual model
    
    */
    exportSerializedVisualModel(): string;
    private _onClosed;
    private _onClosed_wrapped;
    get onClosed(): (s: IgrPopup, e: IgrOnClosedEventArgs) => void;
    set onClosed(ev: (s: IgrPopup, e: IgrOnClosedEventArgs) => void);
    private _onPopup;
    private _onPopup_wrapped;
    /**
     * Fires when the popup is shown
    */
    get onPopup(): (s: IgrPopup, e: IgrOnPopupEventArgs) => void;
    set onPopup(ev: (s: IgrPopup, e: IgrOnPopupEventArgs) => void);
}
export interface IIgrPopupProps {
    width?: string;
    height?: string;
    children?: React.ReactNode;
    /**
 * Gets or sets the duration of the Popup and Closeup animations in milliseconds.
*/
    animationDuration?: number | string;
    /**
     * Gets or sets whether the popup and closeup animations are animated.
    */
    animationEnabled?: boolean | string;
    /**
     * Gets or sets the elevation to use for the button regardless of type.
    */
    elevation?: number | string;
    /**
     * Gets or sets the elevation of the border shadow
    */
    actualElevation?: number | string;
    /**
     * Gets or sets the color to use for the check mark when the checkbox is checked.
    */
    actualUmbraShadowColor?: string;
    /**
     * Gets or sets the color to use for the check mark when the checkbox is checked.
    */
    actualPenumbraShadowColor?: string;
    /**
     * Gets or sets the color to use for the check mark when the checkbox is checked.
    */
    actualAmbientShadowColor?: string;
    /**
     * Gets or sets the background color of the popup.
    */
    background?: string;
    onClosed?: (s: IgrPopup, e: IgrOnClosedEventArgs) => void;
    /**
     * Fires when the popup is shown
    */
    onPopup?: (s: IgrPopup, e: IgrOnPopupEventArgs) => void;
}
